aboutsummaryrefslogtreecommitdiff
path: root/manualtest/src
diff options
context:
space:
mode:
Diffstat (limited to 'manualtest/src')
-rw-r--r--manualtest/src/io/appium/droiddriver/manualtest/ManualTest.java (renamed from manualtest/src/com/google/android/droiddriver/manualtest/ManualTest.java)24
1 files changed, 11 insertions, 13 deletions
diff --git a/manualtest/src/com/google/android/droiddriver/manualtest/ManualTest.java b/manualtest/src/io/appium/droiddriver/manualtest/ManualTest.java
index c1f3946..6e95272 100644
--- a/manualtest/src/com/google/android/droiddriver/manualtest/ManualTest.java
+++ b/manualtest/src/io/appium/droiddriver/manualtest/ManualTest.java
@@ -1,24 +1,22 @@
-package com.google.android.droiddriver.manualtest;
+package io.appium.droiddriver.manualtest;
import android.app.Activity;
-import com.google.android.droiddriver.actions.TextAction;
-import com.google.android.droiddriver.finders.By;
-import com.google.android.droiddriver.finders.Finder;
-import com.google.android.droiddriver.helpers.BaseDroidDriverTest;
-import com.google.android.droiddriver.helpers.DroidDrivers;
+import io.appium.droiddriver.finders.By;
+import io.appium.droiddriver.finders.Finder;
+import io.appium.droiddriver.helpers.BaseDroidDriverTest;
/**
* This is for manually testing DroidDriver. It is not meant for continuous
* testing. Instead it is used for debugging failures. It assumes the device is
* in a condition that is ready to reproduce a failure. For example,
* {@link #testSetTextForPassword} assumes the password_edit field is displayed
- * on screen and has input focus.
+ * on screen.
* <p>
* Run it as (optionally with -e debug true)
*
* <pre>
* adb shell am instrument -w com.google.android.droiddriver.manualtest/com.google.android.droiddriver.runner.TestRunner
* </pre>
*/
public class ManualTest extends BaseDroidDriverTest<Activity> {
@@ -28,13 +26,13 @@ public class ManualTest extends BaseDroidDriverTest<Activity> {
public void testSetTextForPassword() {
Finder password_edit = By.resourceId("com.google.android.gsf.login:id/password_edit");
- driver.on(password_edit).perform(
- new TextAction("A fake password that is not empty and needs to be cleared by setText"));
- String password = "1";
- driver.on(password_edit).setText(password);
+ String oldPassword = "A fake password that is not empty and needs to be cleared by setText";
+ String newPassword = "1";
+ driver.on(password_edit).setText(oldPassword);
+ driver.on(password_edit).setText(newPassword);
// This won't work because password_edit does not reveal text to
// Accessibility service. But you can see the length changed on screen.
- // assertEquals(password, driver.on(password_edit).getText());
+ // assertEquals(newPassword, driver.on(password_edit).getText());
assertEquals(null, driver.on(password_edit).getText());
}
}
@@ -1,24 +1,22 @@
*
* <pre>
- * adb shell am instrument -w com.google.android.droiddriver.manualtest/com.google.android.droiddriver.runner.TestRunner
+ * adb shell am instrument -w io.appium.droiddriver.manualtest/io.appium.droiddriver.runner.TestRunner
* </pre>
*/